@@ -1,5 +1,5 @@
 points.segmented<-function(x, term, interc=TRUE, link=TRUE, 
-    rev.sgn=FALSE, transf=I, .vcov=NULL, .coef=NULL, ...){
+    rev.sgn=FALSE, transf=I, .vcov=NULL, .coef=NULL, const=0, ...){
 #--------------
         f.U<-function(nomiU, term=NULL){
         #trasforma i nomi dei coeff U (o V) nei nomi delle variabili corrispondenti
@@ -21,6 +21,7 @@ points.segmented<-function(x, term, interc=TRUE, link=TRUE,
                else {term<-x$nameUV$Z}
                }
       opz<-list(...)
+      if(is.null(opz$col)) opz$col <- 2
       nameV<- x$nameUV$V[f.U(x$nameUV$V, term)]
       psii<- x$psi[nameV, "Est."]
       d<-data.frame(a=psii)
@@ -30,6 +31,7 @@ points.segmented<-function(x, term, interc=TRUE, link=TRUE,
       opz$x<- psii 
       if(is.null(opz$cex)) opz$cex<-1.5
       if(is.null(opz$lwd)) opz$lwd<-2
+      opz$y <- opz$y + const
       opz$y<-do.call(transf, list(opz$y))
       do.call(points, opz)
       invisible(NULL)
