@@ -803,13 +803,13 @@ segmented.lme <- function(obj, seg.Z, psi, npsi=1, fixed.psi=NULL, control = seg
   RIS$rangeZ<- tapply(Z, id, range)
   names(Z)<-id #names(psi.new)
   RIS$Z<-Z
-  class(RIS)<-"segmented.lme"
+  class(RIS)<- "segmented.lme" #c("segmented.lme","segmented")
   opz.control<-list(...)
   if(!is.null(opz.control$n.boot)) n.boot<- opz.control$n.boot
   if(it >= (it.max+1) && n.boot==0) warning("max no. of iterations achieved.. 'n.boot>0' suggested", call. = FALSE)
   if(n.boot>0){
-    cat("\n..implementing bootstrap restarting..\n")
-    RIS <- reboot.slme(RIS, B=n.boot, display=display, seed=control$seed)#, metodo=1, frac=1, it.max=6, it.max.b=5, start=NULL, msg=TRUE)
+    if(display) cat("Implementing bootstrap restarting..\n")
+    RIS <- reboot.slme(RIS, B=n.boot, display=display, seed=control$seed, msg=display)#, metodo=1, frac=1, it.max=6, it.max.b=5, start=NULL, msg=TRUE)
   }
   RIS
 }
